@@ -960,51 +960,51 @@ String &DateTime::toString(const String &format) const {
             *tmp += "%";
             i++;
         } else if (cformat[i+1] == 'Y') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.date.year);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.date.year);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '4' && cformat[i+3] == 'Y') {
-            ::sprintf(buf, "%04d", (*this).tmpDateTime.date.year);
+            ::snprintf(buf, sizeof(buf), "%04d", (*this).tmpDateTime.date.year);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'm') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.date.mon);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.date.mon);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '2' && cformat[i+3] == 'm') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.date.mon);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.date.mon);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'd') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.date.mday);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.date.mday);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '2' && cformat[i+3] == 'd') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.date.mday);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.date.mday);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'H') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.time.hour);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.time.hour);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '2' && cformat[i+3] == 'H') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.time.hour);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.time.hour);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'M') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.time.min);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.time.min);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '2' && cformat[i+3] == 'M') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.time.min);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.time.min);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'S') {
-            ::sprintf(buf, "%d", (*this).tmpDateTime.time.sec);
+            ::snprintf(buf, sizeof(buf), "%d", (*this).tmpDateTime.time.sec);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == '0' && cformat[i+2] == '2' && cformat[i+3] == 'S') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.time.sec);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.time.sec);
             *tmp += buf;
             i += 3;
         } else if (cformat[i+1] == 'a') {
@@ -1022,7 +1022,7 @@ String &DateTime::toString(const String &format) const {
             }
             i++;
         } else if (cformat[i+1] == 'y') {
-            ::sprintf(buf, "%02d", (*this).tmpDateTime.date.year-1900);
+            ::snprintf(buf, sizeof(buf), "%02d", (*this).tmpDateTime.date.year-1900);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == 'A') {
@@ -1046,10 +1046,10 @@ String &DateTime::toString(const String &format) const {
             } else {
                 *tmp += "+";
             }
-            ::sprintf(buf, "%02ld", gmtoff/3600);
+            ::snprintf(buf, sizeof(buf), "%02ld", gmtoff/3600);
             *tmp += buf;
             *tmp += ":";
-            ::sprintf(buf, "%02ld", gmtoff%3600);
+            ::snprintf(buf, sizeof(buf), "%02ld", gmtoff%3600);
             *tmp += buf;
             i++;
         } else if (cformat[i+1] == 'z') {
@@ -1059,9 +1059,9 @@ String &DateTime::toString(const String &format) const {
             } else {
                 *tmp += "+";
             }
-            ::sprintf(buf, "%02ld", gmtoff/3600);
+            ::snprintf(buf, sizeof(buf), "%02ld", gmtoff/3600);
             *tmp += buf;
-            sprintf(buf, "%02ld", gmtoff%3600);
+            ::snprintf(buf, sizeof(buf), "%02ld", gmtoff%3600);
             *tmp += buf;
             i++;
         }
